@@ -736,7 +736,8 @@ def create_env(prefix, specs, config, clear_cache=True, retry=0):
 
     # ensure prefix exists, even if empty, i.e. when specs are empty
     if not isdir(prefix):
-        os.makedirs(prefix)
+        os.makedirs(join(prefix, 'conda-meta'))
+        open(join(prefix, 'conda-meta', 'history'), 'a').close()
     if utils.on_win:
         shell = "cmd.exe"
     else:
@@ -876,10 +877,16 @@ def bundle_conda(output, metadata, config, env, **kw):
         keep_files = set(utils.expand_globs(files, config.build_prefix))
         pfx_files = set(prefix_files(config.build_prefix))
         initial_files = set(item for item in (pfx_files - keep_files)
-                            if not any(keep_file.startswith(item) for keep_file in keep_files))
+                            if not any(keep_file.startswith(item + os.path.sep)
+                                       for keep_file in keep_files))
 
     files = post_process_files(metadata, initial_files)
 
+    if output.get('name') and output.get('name') != 'conda':
+        assert 'bin/conda' not in files and 'Scripts/conda.exe' not in files, ("Bug in conda-build "
+            "has included conda binary in package. Please report this on the conda-build issue "
+            "tracker.")
+
     output_filename = ('-'.join([output['name'], metadata.version(),
                                  metadata.build_id()]) + '.tar.bz2')
     # first filter is so that info_files does not pick up ignored files
