@@ -5,6 +5,7 @@ Module to handle generating test files.
 from __future__ import absolute_import, division, print_function
 
 import glob
+import logging
 import os
 from os.path import join, exists, isdir
 import sys
@@ -13,31 +14,6 @@ from conda_build.utils import copy_into, get_ext_files, on_win, ensure_list
 from conda_build import source
 
 
-header = '''
-from __future__ import absolute_import, division, print_function
-
-import sys
-import subprocess
-from distutils.spawn import find_executable
-import shlex
-
-
-def call_args(string):
-    args = shlex.split(string)
-    arg0 = args[0]
-    args[0] = find_executable(arg0)
-    if not args[0]:
-        sys.exit("Command not found: '%s'" % arg0)
-
-    try:
-        subprocess.check_call(args)
-    except subprocess.CalledProcessError:
-        sys.exit('Error: command failed: %s' % ' '.join(args))
-
-# --- end header
-'''
-
-
 def create_files(dir_path, m, config):
     """
     Create the test files for pkg in the directory given.  The resulting
@@ -63,8 +39,12 @@ def create_files(dir_path, m, config):
         if not files:
             raise RuntimeError("Did not find any source_files for test with pattern %s", pattern)
         for f in files:
-            copy_into(f, f.replace(config.work_dir, config.test_dir), config.timeout,
-                      locking=config.locking)
+            try:
+                copy_into(f, f.replace(config.work_dir, config.test_dir), config.timeout,
+                        locking=config.locking)
+            except OSError as e:
+                log = logging.getLogger(__name__)
+                log.warn("Failed to copy {0} into test files.  Error was: {1}".format(f, str(e)))
         for ext in '.pyc', '.pyo':
             for f in get_ext_files(config.test_dir, ext):
                 os.remove(f)
@@ -120,7 +100,6 @@ def _create_test_files(dir_path, m, ext, comment_char='# '):
     if os.path.isfile(test_file):
         with open(out_file, 'w') as fo:
             fo.write("%s tests for %s (this is a generated file)\n" % (comment_char, m.dist()))
-            fo.write(header + '\n')
             fo.write("print('===== testing package: %s =====')\n" % m.dist())
 
             try:
@@ -138,12 +117,28 @@ def _create_test_files(dir_path, m, ext, comment_char='# '):
 
 def create_py_files(dir_path, m):
     tf, tf_exists = _create_test_files(dir_path, m, '.py')
-    imports = ensure_list(m.get_value('test/imports', []))
-    for import_item in imports:
-        if (hasattr(import_item, 'keys') and 'lang' in import_item and
-                import_item['lang'] == 'python'):
-            imports = import_item['imports']
-            break
+
+    # Ways in which we can mark imports as none python imports
+    # 1. preface package name with r-, lua- or perl-
+    # 2. use list of dicts for test/imports, and have lang set in those dicts
+    pkg_name = m.name()
+    likely_r_pkg = pkg_name.startswith('r-')
+    likely_lua_pkg = pkg_name.startswith('lua-')
+    likely_perl_pkg = pkg_name.startswith('perl-')
+    likely_non_python_pkg = likely_r_pkg or likely_lua_pkg or likely_perl_pkg
+
+    if likely_non_python_pkg:
+        imports = ensure_list(m.get_value('test/imports', []))
+        for import_item in imports:
+            # add any imports specifically marked as python
+            if (hasattr(import_item, 'keys') and 'lang' in import_item and
+                    import_item['lang'] == 'python'):
+                imports = import_item['imports']
+                break
+    else:
+        imports = ensure_list(m.get_value('test/imports', []))
+        imports = [item for item in imports if (not hasattr(item, 'keys') or
+                                                'lang' in item and item['lang'] == 'python')]
     if imports:
         with open(tf, 'a+') as fo:
             for name in imports:
@@ -192,20 +187,20 @@ def create_pl_files(dir_path, m):
         with open(tf, 'a+') as fo:
             print(r'my $expected_version = "%s";' % m.version().rstrip('0'),
                     file=fo)
-        if imports:
-            for name in imports:
-                print(r'print("import: %s\n");' % name, file=fo)
-                print('use %s;\n' % name, file=fo)
-                # Don't try to print version for complex imports
-                if ' ' not in name:
-                    print(("if (defined {0}->VERSION) {{\n" +
-                            "\tmy $given_version = {0}->VERSION;\n" +
-                            "\t$given_version =~ s/0+$//;\n" +
-                            "\tdie('Expected version ' . $expected_version . ' but" +
-                            " found ' . $given_version) unless ($expected_version " +
-                            "eq $given_version);\n" +
-                            "\tprint('\tusing version ' . {0}->VERSION . '\n');\n" +
-                            "\n}}").format(name), file=fo)
+            if imports:
+                for name in imports:
+                    print(r'print("import: %s\n");' % name, file=fo)
+                    print('use %s;\n' % name, file=fo)
+                    # Don't try to print version for complex imports
+                    if ' ' not in name:
+                        print(("if (defined {0}->VERSION) {{\n" +
+                                "\tmy $given_version = {0}->VERSION;\n" +
+                                "\t$given_version =~ s/0+$//;\n" +
+                                "\tdie('Expected version ' . $expected_version . ' but" +
+                                " found ' . $given_version) unless ($expected_version " +
+                                "eq $given_version);\n" +
+                                "\tprint('\tusing version ' . {0}->VERSION . '\n');\n" +
+                                "\n}}").format(name), file=fo)
     return tf if (tf_exists or imports) else False
 
 
